==> huaweicloudsdkdataartsstudio-3.1.125-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_release_packages_resp_package_approvers.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListReleasePackagesRespPackageApprovers:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'user_id': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'user_name': 'user_name'
    }

    def __init__(self, user_id=None, user_name=None):
        """ListReleasePackagesRespPackageApprovers

        The model defined in huaweicloud sdk

        :param user_id: 发布包审批人id
        :type user_id: str
        :param user_name: 发布包审批人名称
        :type user_name: str
        """
        
        

        self._user_id = None
        self._user_name = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name

    @property
    def user_id(self):
        """Gets the user_id of this ListReleasePackagesRespPackageApprovers.

        发布包审批人id

        :return: The user_id of this ListReleasePackagesRespPackageApprovers.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ListReleasePackagesRespPackageApprovers.

        发布包审批人id

        :param user_id: The user_id of this ListReleasePackagesRespPackageApprovers.
        :type user_id: str
        """
        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this ListReleasePackagesRespPackageApprovers.

        发布包审批人名称

        :return: The user_name of this ListReleasePackagesRespPackageApprovers.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this ListReleasePackagesRespPackageApprovers.

        发布包审批人名称

        :param user_name: The user_name of this ListReleasePackagesRespPackageApprovers.
        :type user_name: str
        """
        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListReleasePackagesRespPackageApprovers):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_release_packages_resp_package_approvers.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListReleasePackagesRespPackageApprovers:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'user_id': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'user_name': 'user_name'
    }

    def __init__(self, user_id=None, user_name=None):
        r"""ListReleasePackagesRespPackageApprovers

        The model defined in huaweicloud sdk

        :param user_id: 发布包审批人id
        :type user_id: str
        :param user_name: 发布包审批人名称
        :type user_name: str
        """
        
        

        self._user_id = None
        self._user_name = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name

    @property
    def user_id(self):
        r"""Gets the user_id of this ListReleasePackagesRespPackageApprovers.

        发布包审批人id

        :return: The user_id of this ListReleasePackagesRespPackageApprovers.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        r"""Sets the user_id of this ListReleasePackagesRespPackageApprovers.

        发布包审批人id

        :param user_id: The user_id of this ListReleasePackagesRespPackageApprovers.
        :type user_id: str
        """
        self._user_id = user_id

    @property
    def user_name(self):
        r"""Gets the user_name of this ListReleasePackagesRespPackageApprovers.

        发布包审批人名称

        :return: The user_name of this ListReleasePackagesRespPackageApprovers.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        r"""Sets the user_name of this ListReleasePackagesRespPackageApprovers.

        发布包审批人名称

        :param user_name: The user_name of this ListReleasePackagesRespPackageApprovers.
        :type user_name: str
        """
        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListReleasePackagesRespPackageApprovers):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
